<?php

namespace CustomForm\Model;

use Boutique;
use Model;
use Query;

/**
 * Class CustomForm
 *
 * @property int $form_id
 * @property string $form_nom_success
 */
class Form extends Model
{
    protected $table = "form";

    /**
     * @var FormField[]
     */
    protected $fields = [];

    public function get($formvars = array())
    {
        $q = new Query();
        $boutique = Boutique::getInstance();
        $q->select('*')
            ->from('form')
            ->leftJoin('form_nom', "AND", ['fn.form_id', 'f.form_id'], ['fn.langue_id', $boutique->getLangue()->id])
            ->innerJoin('form_boutique', 'AND',
                ['fb.form_id', 'f.form_id'],
                ['fb.boutique_id', $boutique->id],
                ['fb.form_boutique_statut_id', 1]
            )
            ->where('f.form_statut_id', 1)
        ;

        if (!empty($formvars['form_id'])) {
            $q->where('f.form_id', $formvars['form_id']);
        }

        if (!empty($formvars['form_nom_url'])) {
            $q->where('fn.form_nom_url', $formvars['form_nom_url']);
        }

        return $this->sql->getAll($q->build());
    }

    public function getOne($formvars = array())
    {
        if (!empty($formvars['f.form_id'])) {
            $formvars['form_id'] = $formvars['f.form_id'];
        }
        $result = $this->get($formvars);

        return (!empty($result)) ? $result[0] : array();
    }

    /**
     * @return FormField[]
     */
    public function getFields()
    {
        return $this->fields;
    }

    /**
     * @param FormField[] $fields
     * @return Form
     */
    public function setFields($fields)
    {
        $this->fields = $fields;
        return $this;
    }

    /**
     * @param FormField $fields
     * @return Form
     */
    public function addFields(FormField $fields)
    {
        $this->fields[] = $fields;
        return $this;
    }

    /**
     * @return int
     */
    public function getFormId()
    {
        return $this->form_id;
    }

    /**
     * @param int $form_id
     * @return Form
     */
    public function setFormId($form_id)
    {
        $this->form_id = $form_id;
        return $this;
    }

    /**
     * @return string
     */
    public function getFormNomSuccess()
    {
        return $this->form_nom_success;
    }

    /**
     * @param string $form_nom_success
     * @return Form
     */
    public function setFormNomSuccess($form_nom_success)
    {
        $this->form_nom_success = $form_nom_success;
        return $this;
    }
}