<?php

namespace CustomForm\Tests\Model;

use CustomForm\Model\Form;
use CustomForm\Tests\ByDediDbTestCase;

/**
 * Created by PhpStorm.
 * User: gabriel
 * Date: 25/05/18
 * Time: 13:24
 */
class FormTest extends ByDediDbTestCase
{
    protected function getDataSet()
    {
        return $this->createArrayDataSet([
            'form' => [
                ['form_id' => 1, 'form_statut_id' => 1],
                ['form_id' => 2, 'form_statut_id' => 1],
                ['form_id' => 3, 'form_statut_id' => 1],
                ['form_id' => 4, 'form_statut_id' => 1],
                ['form_id' => 5, 'form_statut_id' => 1],
                ['form_id' => 6, 'form_statut_id' => 2],
            ],
            'form_boutique' => [
                [
                    'form_id' => 1,
                    'boutique_id' => 1,
                    'form_boutique_statut_id' => 1
                ],
                [
                    'form_id' => 2,
                    'boutique_id' => 1,
                    'form_boutique_statut_id' => 2
                ],
                [
                    'form_id' => 4,
                    'boutique_id' => 2,
                    'form_boutique_statut_id' => 1
                ],
                [
                    'form_id' => 5,
                    'boutique_id' => 2,
                    'form_boutique_statut_id' => 1
                ],
            ],
            'form_nom' => [
                [
                    'form_id' => 1,
                    'langue_id' => 1,
                    'form_nom_nom' => "Test French"
                ],
            ]
        ]);
    }


    public function getProvider()
    {
        $data = [
            [1, null, null, 1, null],
            [2, null, null, 2, null],
            [1, 1, 1, 1, 'Test French'],
        ];

        return $data;
    }

    /**
     * @dataProvider getProvider
     */
    public function testGet($boutiqueId, $langueId, $formId, $countExpected, $nameExpected)
    {
        \Boutique::loadById($boutiqueId);
        if (!empty($langueId)) {
            \Boutique::getInstance()->setLangue(new \Langue($langueId));
        }
        $form = new Form();
        $result = $form->get(['form_id' => $formId]);
        $this->assertCount($countExpected, $result);
        if (!empty($nameExpected)) {
            $this->assertNotEmpty($result[0]['form_nom_nom']);
            $this->assertEquals($nameExpected, $result[0]['form_nom_nom']);
        }
    }

    /**
     * @dataProvider getProvider
     */
    public function testGetOne($boutiqueId, $langueId, $formId, $countExpected, $nameExpected)
    {
        \Boutique::loadById($boutiqueId);
        if (!empty($langueId)) {
            \Boutique::getInstance()->setLangue(new \Langue($langueId));
        }
        $form = new Form();
        $result = $form->getOne(['form_id' => $formId]);
        if ($countExpected > 0) {
            $this->assertNotEmpty($result);
        } else {
            $this->assertEmpty($result);
        }
        if (!empty($nameExpected)) {
            $this->assertNotEmpty($result['form_nom_nom']);
            $this->assertEquals($nameExpected, $result['form_nom_nom']);
        }
    }
}